@@ -1,4 +1,5 @@
 import os
+import site
 from datetime import datetime
 import time
 import tkinter as tk
@@ -20,6 +21,7 @@ def get_text():
 master = tk.Tk()
 master.title('auto zoom join by snir')
 master.configure(background="#2A3240")
+master.iconbitmap(fr"{site.getsitepackages()[1]}\snirwhatsapp\icon.ico")
 
 ok_button = tk.Button(master, text='OK', command=get_text, width=3, height=1, font=("Consolas", 35))
 ok_button.place(x=850, y=422)
